Finnish_monetary_institution_codes_and_BICs_in_excel_format.csv
Source: http://www.finanssiala.fi/maksujenvalitys/dokumentit/Finnish_monetary_institution_codes_and_BICs_in_excel_format.xlsx

Swedish-Bankernas-kontonummer.csv
Source: https://www-2.danskebank.se/link/Bankernaskontonummer
